Enum Dtae
#[repr(u8)]pub enum Dtae {
Identical = 0,
Distinct = 1,
}Variants
Identical = 0
Deadtime on rising and falling edges are identical, and defined with DTG[7:0] register
Distinct = 1
Deadtime on rising edge is defined with DTG[7:0] register and deadtime on falling edge is defined with DTGF[7:0] bits.
Implementations